﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;

namespace AppointmentMapping_SfSchedule_WinRT
{
    public class EventViewModel : BindableBase
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="EventViewModel"/> class.
        /// </summary>
        /// <param name="eventInstance">The event instance.</param>
        /// <param name="isNew">if set to <c>true</c> [is new].</param>
        public EventViewModel()
        {

        }

        private string _subject = "new";
        public string Subject
        {
            get
            {
                return _subject;
            }
            set
            {
                this.SetProperty(ref _subject, value);
            }
        }

        private string _body = string.Empty;
        public string Body
        {
            get
            {
                return _body;
            }
            set
            {
                this.SetProperty(ref _body, value);
            }
        }

        private DateTime _startDateTime = DateTime.MinValue;
        public DateTime StartDateTime
        {
            get
            {
                return _startDateTime;

            }
            set
            {
                this.SetProperty(ref _startDateTime, value);
            }
        }


        private DateTime _endDateTime = DateTime.MinValue;
        public DateTime EndDateTime
        {
            get
            {
                return _endDateTime;

            }
            set
            {
                this.SetProperty(ref _endDateTime, value);
            }
        }



    }

    public abstract class BindableBase : INotifyPropertyChanged
    {
        /// <summary>
        /// Multicast event for property change notifications.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Checks if a property already matches a desired value.  Sets the property and
        /// notifies listeners only when necessary.
        /// </summary>
        /// <typeparam name="T">Type of the property.</typeparam>
        /// <param name="storage">Reference to a property with both getter and setter.</param>
        /// <param name="value">Desired value for the property.</param>
        /// <param name="propertyName">Name of the property used to notify listeners.  This
        /// value is optional and can be provided automatically when invoked from compilers that
        /// support CallerMemberName.</param>
        /// <returns>True if the value was changed, false if the existing value matched the
        /// desired value.</returns>
        protected bool SetProperty<T>(ref T storage, T value, [CallerMemberName] String propertyName = null)
        {
            if (object.Equals(storage, value)) return false;

            storage = value;
            this.OnPropertyChanged(propertyName);
            return true;
        }

        /// <summary>
        /// Notifies listeners that a property value has changed.
        /// </summary>
        /// <param name="propertyName">Name of the property used to notify listeners.  This
        /// value is optional and can be provided automatically when invoked from compilers
        /// that support <see cref="CallerMemberNameAttribute"/>.</param>
        protected void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            var eventHandler = this.PropertyChanged;
            if (eventHandler != null)
            {
                eventHandler(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
